__title__ = "randfacts"
__description__ = "Package to generate random facts"
__url__ = "https://github.com/TabulateJarl8/randfacts"
__version__ = "0.13.0"
__author__ = "Tabulate"
__author_email__ = "tabulatejarl8@gmail.com"
__license__ = "MIT"
__copyright__ = "Copyright 2020-2021 Connor Sample"



"""Module to generate random facts.

randfacts provides an interface to a list of facts installed with the module.
You can retrieve facts via the getFact method. randfacts also allows for
execution via the command line. See the examples section for more details.

Code Examples:
		Example usage of randfacts in code.

		Generate a random safe fact.

			>>> randfacts.get_fact()

		Generate a random unsafe fact.

			>>> randfacts.get_fact(only_unsafe=True)

		Generate a random mixed fact (possibility of both safe and unsafe facts)

			>>> randfacts.get_fact(False)
			>>> # or
			>>> randfacts.get_fact(filter_enabled=False)

CLI Examples:
	randfacts can be executed via the command line with the following commands:

	Normal execution; only safe facts

		$ python3 -m randfacts

	The unsafe argument can be supplied to provide only unsafe facts

		$ python3 -m randfacts --unsafe

	The mixed argument can be provided to provide both safe and unsafe facts.

		$ python3 -m randfacts --mixed

	More help.

		$ python3 -m randfacts --help

"""

from .__version__ import __title__, __description__, __url__, __version__, __author__, __author_email__, __license__, __copyright__
from randfacts.randfacts import get_fact, safe_facts, unsafe_facts, all_facts

import warnings as _warnings
# Deprecated methods
def getFact(filter_enabled=True, only_unsafe=False):
	"""This method is deprecated. Please use get_fact"""
	_warnings.warn("getFact is deprecated. Please use get_fact", DeprecationWarning, stacklevel=2)
	return get_fact(filter_enabled, only_unsafe)



from random import choice
import os
import argparse

dir_path = os.path.dirname(os.path.realpath(__file__))

with open(os.path.join(dir_path, 'safe.txt'), encoding='utf-8') as f:
	safe_facts = [
		fact.rstrip('\r\n ')
		for fact in f.readlines()
		if fact.rstrip('\r\n ') != ''
	]

with open(os.path.join(dir_path, 'unsafe.txt'), encoding='utf-8') as f:
	unsafe_facts = [
		fact.rstrip('\r\n ')
		for fact in f.readlines()
		if fact.rstrip('\r\n ') != ''
	]

all_facts = safe_facts + unsafe_facts


def get_fact(filter_enabled: bool = True, only_unsafe: bool = False) -> str:
	"""This function returns a random fact.

	Parameters
	----------
	filter_enabled : bool
		The `filter_enabled` parameter determines if the function will filter
		out potentially inappropriate facts. Defaults to True.

	only_unsafe : bool
		The `only_unsafe` parameter determines if the function will only give
		unsafe facts. Takes precedence over the `filter_enabled` argument.

	Returns
	------
	str
		A random fact.

	"""

	if only_unsafe:
		return choice(unsafe_facts)
	if filter_enabled is False:
		return choice(all_facts)
	return choice(safe_facts)


def _cli_entrypoint():
	"""Entrypoint for execution via command-line."""

	parser = argparse.ArgumentParser(
		description='Generate random facts from the command-line'
	)

	group = parser.add_mutually_exclusive_group()
	group.add_argument(
		'-m',
		'--mixed',
		action='store_true',
		help='Include safe and unsafe facts'
	)

	group.add_argument(
		'-u',
		'--unsafe',
		action='store_true',
		help='Only include unsafe facts'
	)

	args = parser.parse_args()

	if args.mixed:
		print(get_fact(False))
	elif args.unsafe:
		print(get_fact(only_unsafe=True))
	else:
		print(get_fact())


if __name__ == '__main__':
	_cli_entrypoint()



import pathlib
import setuptools

here = pathlib.Path(__file__).parent.resolve()

with open(here / "README.md", "r") as fh:
	long_description = fh.read()

about = {}
with open(here / "randfacts/__version__.py", "r") as f:
	exec(f.read(), about)

packages = ['randfacts']

setuptools.setup(
	name=about["__title__"],
	version=about["__version__"],
	author=about["__author__"],
	author_email=about["__author_email__"],
	description=about["__description__"],
	long_description=long_description,
	long_description_content_type="text/markdown",
	url=about["__url__"],
	packages=packages,
	package_dir={'randfacts': 'randfacts'},
	classifiers=[
		"Programming Language :: Python :: 3",
		"Programming Language :: Python :: 3.6",
		"Programming Language :: Python :: 3.7",
		"Programming Language :: Python :: 3.8",
		"Programming Language :: Python :: 3.9",
		"Natural Language :: English",
		"License :: OSI Approved :: MIT License",
		"Operating System :: OS Independent",
		"Development Status :: 5 - Production/Stable",
		"Intended Audience :: Developers"
	],
	python_requires='>=3.6',
	include_package_data=True
)
